@@ -17,15 +17,18 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef LIBKGAPI2_EVENTCREATEJOB_H
 #define LIBKGAPI2_EVENTCREATEJOB_H
 
 #include "createjob.h"
+#include "enums.h"
 #include "kgapicalendar_export.h"
 
+#include <QScopedPointer>
+
 namespace KGAPI2 {
 
 /**
@@ -38,8 +41,11 @@ class KGAPICALENDAR_EXPORT EventCreateJob : public KGAPI2::CreateJob
 {
     Q_OBJECT
 
+    Q_PROPERTY(KGAPI2::SendUpdatesPolicy sendUpdates
+               READ sendUpdates
+               WRITE setSendUpdates
+               NOTIFY sendUpdatesChanged)
   public:
-
     /**
      * @brief Constructs a job that will create given @p event in a calendar
      *        with given @p calendarID
@@ -67,7 +73,13 @@ class KGAPICALENDAR_EXPORT EventCreateJob : public KGAPI2::CreateJob
     /**
      * @brief Destructor
      */
-    virtual ~EventCreateJob();
+    ~EventCreateJob() override;
+
+    KGAPI2::SendUpdatesPolicy sendUpdates() const;
+    void setSendUpdates(KGAPI2::SendUpdatesPolicy updatePolicy);
+
+  Q_SIGNALS:
+    void sendUpdatesChanged(KGAPI2::SendUpdatesPolicy policy);
 
   protected:
 
@@ -86,7 +98,7 @@ class KGAPICALENDAR_EXPORT EventCreateJob : public KGAPI2::CreateJob
 
   private:
     class Private;
-    Private * const d;
+    QScopedPointer<Private> const d;
     friend class Private;
 
 };
